Package: shinyWidgets
Title: Custom Inputs Widgets for Shiny
Version: 0.4.3
Authors@R: c(
  person("Victor", "Perrier", email = "victor.perrier@dreamrs.fr", role = c("aut", "cre")),
  person("Fanny", "Meyer", email = "fanny.meyer@dreamrs.fr", role = c("aut")),
  person("David", "Granjon", email = "david.granjon@uzh.ch", role = "aut",
         comment = "jQuery Knob shiny interface & sliders appearance"),
  person("Silvio", "Moreto", role = c("ctb", "cph"), comment = "bootstrap-select"),
  person("Ana", "Carolina", role = c("ctb", "cph"), comment = "bootstrap-select"),
  person("caseyjhol", role = c("ctb", "cph"), comment = "bootstrap-select"),
  person("Matt", "Bryson", role = c("ctb", "cph"), comment = "bootstrap-select"),
  person("t0xicCode", role = c("ctb", "cph"), comment = "bootstrap-select"),
  person("Mattia", "Larentis", role = c("ctb", "cph"), comment = "Bootstrap Switch"),
  person("Emanuele", "Marchi", role = c("ctb", "cph"), comment = "Bootstrap Switch"),
  person("Mark", "Otto", role = "ctb", comment = "Bootstrap library"),
  person("Jacob", "Thornton", role = "ctb", comment = "Bootstrap library"),
  person(family = "Bootstrap contributors", role = "ctb", comment = "Bootstrap library"),
  person(family = "Twitter, Inc", role = "cph", comment = "Bootstrap library"),
  person(family = "Flatlogic", role = "cph", comment = "Awesome Bootstrap Checkbox"),
  person("mouse0270", role = c("ctb", "cph"), comment = "Material Design Switch"),
  person("Tristan", "Edwards", role = c("ctb", "cph"), comment = "SweetAlert"),
  person("Fabian", "Lindfors", role = c("ctb", "cph"), comment = "multi.js"),
  person("Anthony", "Terrien", role = c("ctb", "cph"), comment = "jQuery Knob"),
  person("Daniel", "Eden", role = c("ctb", "cph"), comment = "animate.css"),
  person("Ganapati", "V S", role = c("ctb", "cph"), comment = "bttn.css"),
  person("Brian", "Grinstead", role = c("ctb", "cph"), comment = "Spectrum"),
  person("Lokesh", "Rajendran", role = c("ctb", "cph"), comment = "pretty-checkbox"),
  person("Leon", "Gersen", role = c("ctb", "cph"), comment = "wnumb & noUiSlider"),
  person("Timofey", "Marochkin", role = c("ctb", "cph"), comment = "air-datepicker"),
  person("Tobias", "Ahlin", role = c("ctb", "cph"), comment = "CSS spin")
  )
Description: Some custom inputs widgets to use in Shiny applications, like a toggle switch to replace checkboxes. And other components to pimp your apps.
URL: https://github.com/dreamRs/shinyWidgets
BugReports: https://github.com/dreamRs/shinyWidgets/issues
Depends: R (>= 3.1.0)
Imports: shiny (>= 0.14), htmltools, jsonlite, grDevices
License: GPL-3 | file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1
Suggests: shinydashboard, viridisLite, RColorBrewer, testthat, covr,
        shinydashboardPlus
NeedsCompilation: no
Packaged: 2018-05-30 09:03:29 UTC; perri
Author: Victor Perrier [aut, cre],
  Fanny Meyer [aut],
  David Granjon [aut] (jQuery Knob shiny interface & sliders appearance),
  Silvio Moreto [ctb, cph] (bootstrap-select),
  Ana Carolina [ctb, cph] (bootstrap-select),
  caseyjhol [ctb, cph] (bootstrap-select),
  Matt Bryson [ctb, cph] (bootstrap-select),
  t0xicCode [ctb, cph] (bootstrap-select),
  Mattia Larentis [ctb, cph] (Bootstrap Switch),
  Emanuele Marchi [ctb, cph] (Bootstrap Switch),
  Mark Otto [ctb] (Bootstrap library),
  Jacob Thornton [ctb] (Bootstrap library),
  Bootstrap contributors [ctb] (Bootstrap library),
  Twitter, Inc [cph] (Bootstrap library),
  Flatlogic [cph] (Awesome Bootstrap Checkbox),
  mouse0270 [ctb, cph] (Material Design Switch),
  Tristan Edwards [ctb, cph] (SweetAlert),
  Fabian Lindfors [ctb, cph] (multi.js),
  Anthony Terrien [ctb, cph] (jQuery Knob),
  Daniel Eden [ctb, cph] (animate.css),
  Ganapati V S [ctb, cph] (bttn.css),
  Brian Grinstead [ctb, cph] (Spectrum),
  Lokesh Rajendran [ctb, cph] (pretty-checkbox),
  Leon Gersen [ctb, cph] (wnumb & noUiSlider),
  Timofey Marochkin [ctb, cph] (air-datepicker),
  Tobias Ahlin [ctb, cph] (CSS spin)
Maintainer: Victor Perrier <victor.perrier@dreamrs.fr>
Repository: CRAN
Date/Publication: 2018-05-30 09:27:59 UTC
Built: R 3.5.1; ; 2018-10-04 10:25:42 UTC; windows
