# Generated by roxygen2: do not edit by hand

export(actionBttn)
export(actionGroupButtons)
export(addSpinner)
export(airDatepickerInput)
export(airMonthpickerInput)
export(airYearpickerInput)
export(animateOptions)
export(awesomeCheckbox)
export(awesomeCheckboxGroup)
export(awesomeRadio)
export(checkboxGroupButtons)
export(chooseSliderSkin)
export(circleButton)
export(closeSweetAlert)
export(colorSelectorDrop)
export(colorSelectorExample)
export(colorSelectorInput)
export(confirmSweetAlert)
export(demoAirDatepicker)
export(demoNoUiSlider)
export(downloadBttn)
export(dropdown)
export(dropdownButton)
export(inputSweetAlert)
export(knobInput)
export(materialSwitch)
export(multiInput)
export(noUiSliderInput)
export(panel)
export(pickerGroupServer)
export(pickerGroupUI)
export(pickerInput)
export(prettyCheckbox)
export(prettyCheckboxGroup)
export(prettyRadioButtons)
export(prettySwitch)
export(prettyToggle)
export(progressBar)
export(progressSweetAlert)
export(radioGroupButtons)
export(searchInput)
export(selectizeGroupServer)
export(selectizeGroupUI)
export(sendSweetAlert)
export(setBackgroundColor)
export(setBackgroundImage)
export(setSliderColor)
export(shinyWidgetsGallery)
export(sliderTextInput)
export(spectrumInput)
export(switchInput)
export(textInputAddon)
export(timepickerOptions)
export(toggleDropdownButton)
export(tooltipOptions)
export(updateAirDateInput)
export(updateAwesomeCheckbox)
export(updateAwesomeCheckboxGroup)
export(updateAwesomeRadio)
export(updateCheckboxGroupButtons)
export(updateKnobInput)
export(updateMaterialSwitch)
export(updateNoUiSliderInput)
export(updatePickerInput)
export(updatePrettyCheckbox)
export(updatePrettyCheckboxGroup)
export(updatePrettyRadioButtons)
export(updatePrettySwitch)
export(updatePrettyToggle)
export(updateProgressBar)
export(updateRadioGroupButtons)
export(updateSearchInput)
export(updateSliderTextInput)
export(updateSpectrumInput)
export(updateSwitchInput)
export(useShinydashboard)
export(useShinydashboardPlus)
export(useSweetAlert)
export(wNumbFormat)
importFrom(grDevices,col2rgb)
importFrom(grDevices,rgb2hsv)
importFrom(htmltools,HTML)
importFrom(htmltools,attachDependencies)
importFrom(htmltools,findDependencies)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,htmlEscape)
importFrom(htmltools,singleton)
importFrom(htmltools,tagAppendChild)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(htmltools,validateCssUnit)
importFrom(jsonlite,toJSON)
importFrom(shiny,NS)
importFrom(shiny,actionLink)
importFrom(shiny,addResourcePath)
importFrom(shiny,animationOptions)
importFrom(shiny,getDefaultReactiveDomain)
importFrom(shiny,icon)
importFrom(shiny,insertUI)
importFrom(shiny,observe)
importFrom(shiny,observeEvent)
importFrom(shiny,reactive)
importFrom(shiny,reactiveValues)
importFrom(shiny,reactiveValuesToList)
importFrom(shiny,registerInputHandler)
importFrom(shiny,restoreInput)
importFrom(shiny,selectizeInput)
importFrom(shiny,shinyAppDir)
importFrom(shiny,shinyAppFile)
importFrom(shiny,singleton)
importFrom(shiny,sliderInput)
importFrom(shiny,updateSelectizeInput)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(utils,capture.output)
importFrom(utils,modifyList)
importFrom(utils,packageVersion)
