# Generated by roxygen2: do not edit by hand

export(WinBox)
export(actionBttn)
export(actionGroupButtons)
export(addSpinner)
export(airDatepickerInput)
export(airMonthpickerInput)
export(airYearpickerInput)
export(alert)
export(animateOptions)
export(appendVerticalTab)
export(applyWinBox)
export(ask_confirmation)
export(autonumericInput)
export(awesomeCheckbox)
export(awesomeCheckboxGroup)
export(awesomeRadio)
export(checkboxGroupButtons)
export(chooseSliderSkin)
export(circleButton)
export(closeSweetAlert)
export(closeWinBox)
export(colorPickr)
export(colorSelectorDrop)
export(colorSelectorExample)
export(colorSelectorInput)
export(confirmSweetAlert)
export(create_tree)
export(currencyInput)
export(demoAirDatepicker)
export(demoNoUiSlider)
export(demoNumericRange)
export(demoVirtualSelect)
export(disableDropMenu)
export(downloadBttn)
export(dropMenu)
export(dropMenuOptions)
export(dropdown)
export(dropdownButton)
export(enableDropMenu)
export(execute_safely)
export(formatNumericInput)
export(hideDropMenu)
export(html_dependency_awesome)
export(html_dependency_bsswitch)
export(html_dependency_bttn)
export(html_dependency_pretty)
export(html_dependency_sweetalert2)
export(html_dependency_winbox)
export(inputSweetAlert)
export(knobInput)
export(list_group)
export(materialSwitch)
export(multiInput)
export(noUiSliderInput)
export(numericInputIcon)
export(numericRangeInput)
export(panel)
export(pickerGroupServer)
export(pickerGroupUI)
export(pickerInput)
export(pickerOptions)
export(prepare_choices)
export(prepare_slim_choices)
export(prettyCheckbox)
export(prettyCheckboxGroup)
export(prettyRadioButtons)
export(prettySwitch)
export(prettyToggle)
export(progressBar)
export(progressSweetAlert)
export(radioGroupButtons)
export(removeVerticalTab)
export(reorderVerticalTabs)
export(searchInput)
export(selectizeGroupServer)
export(selectizeGroupUI)
export(sendSweetAlert)
export(setBackgroundColor)
export(setBackgroundImage)
export(setShadow)
export(setSliderColor)
export(shinyWidgetsGallery)
export(showDropMenu)
export(show_alert)
export(show_toast)
export(sliderTextInput)
export(slimSelectInput)
export(spectrumInput)
export(statiCard)
export(switchInput)
export(textInputAddon)
export(textInputIcon)
export(timeInput)
export(timepickerOptions)
export(toggleDropdownButton)
export(tooltipOptions)
export(treeInput)
export(updateAirDateInput)
export(updateAutonumericInput)
export(updateAwesomeCheckbox)
export(updateAwesomeCheckboxGroup)
export(updateAwesomeRadio)
export(updateCheckboxGroupButtons)
export(updateColorPickr)
export(updateCurrencyInput)
export(updateKnobInput)
export(updateMaterialSwitch)
export(updateMultiInput)
export(updateNoUiSliderInput)
export(updateNumericInputIcon)
export(updateNumericRangeInput)
export(updatePickerInput)
export(updatePrettyCheckbox)
export(updatePrettyCheckboxGroup)
export(updatePrettyRadioButtons)
export(updatePrettySwitch)
export(updatePrettyToggle)
export(updateProgressBar)
export(updateRadioGroupButtons)
export(updateSearchInput)
export(updateSliderTextInput)
export(updateSlimSelect)
export(updateSpectrumInput)
export(updateStatiCard)
export(updateSwitchInput)
export(updateTextInputIcon)
export(updateTimeInput)
export(updateTreeInput)
export(updateVerticalTabsetPanel)
export(updateVirtualSelect)
export(useArgonDash)
export(useBs4Dash)
export(useShinydashboard)
export(useShinydashboardPlus)
export(useSweetAlert)
export(useTablerDash)
export(verticalTabPanel)
export(verticalTabsetPanel)
export(virtualSelectInput)
export(wNumbFormat)
export(wbControls)
export(wbOptions)
importFrom(bslib,bs_dependency)
importFrom(bslib,bs_dependency_defer)
importFrom(bslib,is_bs_theme)
importFrom(bslib,theme_version)
importFrom(grDevices,col2rgb)
importFrom(grDevices,rgb2hsv)
importFrom(htmltools,HTML)
importFrom(htmltools,as.tags)
importFrom(htmltools,attachDependencies)
importFrom(htmltools,css)
importFrom(htmltools,doRenderTags)
importFrom(htmltools,findDependencies)
importFrom(htmltools,htmlDependencies)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,htmlEscape)
importFrom(htmltools,singleton)
importFrom(htmltools,tag)
importFrom(htmltools,tagAppendAttributes)
importFrom(htmltools,tagAppendChild)
importFrom(htmltools,tagAppendChildren)
importFrom(htmltools,tagFunction)
importFrom(htmltools,tagGetAttribute)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(htmltools,validateCssUnit)
importFrom(jsonlite,toJSON)
importFrom(rlang,"%||%")
importFrom(rlang,enexprs)
importFrom(rlang,eval_tidy)
importFrom(rlang,has_name)
importFrom(rlang,is_bare_atomic)
importFrom(rlang,is_list)
importFrom(rlang,is_named)
importFrom(rlang,is_null)
importFrom(sass,sass)
importFrom(sass,sass_file)
importFrom(shiny,NS)
importFrom(shiny,actionLink)
importFrom(shiny,addResourcePath)
importFrom(shiny,animationOptions)
importFrom(shiny,getCurrentTheme)
importFrom(shiny,getDefaultReactiveDomain)
importFrom(shiny,icon)
importFrom(shiny,insertUI)
importFrom(shiny,is.reactive)
importFrom(shiny,isolate)
importFrom(shiny,observe)
importFrom(shiny,observeEvent)
importFrom(shiny,reactive)
importFrom(shiny,reactiveValues)
importFrom(shiny,reactiveValuesToList)
importFrom(shiny,registerInputHandler)
importFrom(shiny,restoreInput)
importFrom(shiny,runApp)
importFrom(shiny,selectizeInput)
importFrom(shiny,shinyAppDir)
importFrom(shiny,shinyAppFile)
importFrom(shiny,singleton)
importFrom(shiny,sliderInput)
importFrom(shiny,updateSelectizeInput)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,setNames)
importFrom(utils,modifyList)
importFrom(utils,packageVersion)
